

library(ggplot2)
library(ggpubr)
library(dplyr)
library(plm)
library(lmtest)
library(stringr)
library(rstanarm)
library(bayestestR)
library(stargazer)

setwd("C:/Users/jerry/Dropbox (MIT)/Partisan Bias in Advice-taking Replication Materials")

truth = c(4,4,3,3,5,5,5,5,5,5)

se_func = function(x, n){sd(x) / sqrt(n)}
se_func2 = function(x, n){sd(x, na.rm = T) / sqrt( n - sum(is.na(x)))}
main_df = read.csv("main_df.csv")
main_df = main_df %>%
  mutate(Oppo_center = Oppo*2-1,
         Right = ifelse(REP,Political.Leaning-4,Political.Leaning-6),
         High_Incentive_center = (Incentive=="High")*2-1,
         perf_incentive_center = (perf_incentive-1)*2-1,
         update3 = (distance-abs(updated_rating-advice))/(distance+1),
         Feedback_center = (Feedback=="Counter-Better")*2-1,
         REP_center = 2*REP - 1 )

news_perf_func = function(x,truth, news_num){
  abs(x-truth[news_num])
}

news_perf = sapply(main_df$initial_rating, news_perf_func, main_df$truth, as.numeric(main_df$news_num))
sum(main_df$update != 0 & main_df$distance == 0)
summary(main_df$time_taken/60)

# DF for subsample Robustness Checks

dem_df = main_df[main_df$REP == 0, ]
rep_df = main_df[main_df$REP == 1, ]
df_turk = main_df[main_df$is_turk == T, ]
df_prolific = main_df[main_df$is_turk == F,]
dem_df_turk = main_df[main_df$REP == 0 & main_df$is_turk == T, ]
rep_df_turk = main_df[main_df$REP == 1 & main_df$is_turk == T, ]

#sum(dem_df$Gender) / nrow(dem_df) # Dem Feamel
#sum(rep_df$Gender) / nrow(rep_df) # Republican Female

#mean(dem_df$Age)  # Dem Age
#mean(rep_df$Age)  # Rep Age



dem_headline = data.frame(main_df$initial_rating[main_df$REP == 0], main_df$news_num[main_df$REP == 0])
rep_headline = data.frame(main_df$initial_rating[main_df$REP == 1], main_df$news_num[main_df$REP == 1])

news_answer_list = list()
news_accuracy_list = list()
news_cohen_list = list()
news_cohen_accuracy_list = list()

library(lsr)

# The following codes are for SI Section 2
# The following codes are for SI Section 2
# The following codes are for SI Section 2

for(i in 1:10){
  print(i)
  news_answer_list[[i]] = t.test(dem_headline[dem_headline[,2] == as.character(i), 1], rep_headline[rep_headline[,2] == as.character(i),1])
  news_accuracy_list[[i]] = t.test(abs(dem_headline[dem_headline[,2] == as.character(i), 1] - truth[i]), abs(rep_headline[rep_headline[,2] == as.character(i),1] - truth[i]))
  news_cohen_list[[i]] = cohensD(dem_headline[dem_headline[,2] == as.character(i), 1], rep_headline[rep_headline[,2] == as.character(i),1])
  news_cohen_accuracy_list[[i]] = cohensD(abs(dem_headline[dem_headline[,2] == as.character(i), 1] - truth[i]), abs(rep_headline[rep_headline[,2] == as.character(i),1] - truth[i]))
  
}
sum(main_df$distance == 0) / nrow(main_df)
#news_cohen_list
#news_cohen_accuracy_list

# The codes for SI Section 2 have ended

main_df_sub = main_df[main_df$news_num!= "2" & main_df$news_num!= "10",]

#################

# Plots in the main text

pooled_plot_dist <- main_df%>% 
  
  filter(distance != 0) %>%
  group_by(ID, High_Task_Incentive, Subject
           #,Political.Leaning
  ) %>% 
  summarise(dev = mean(update, na.rm = T),
            n = n(),
            dev_se = se_func2(update, n)) 
pooled_plot_dist$Subject = ifelse(pooled_plot_dist$Subject == "REP", "Republican Subjects", "Democratic Subjects")


#rep_plot_dist <- rep_df %>% 
#  filter(distance != 0) %>%
  
#  group_by(ID, High_Task_Incentive
           #,Political.Leaning
#  ) %>% 
#  summarise(dev = mean(update, na.rm = T),
#            n = n(),
#            dev_se = se_func2(update, n)) 

#dem_plot_dist <- dem_df %>% 
#  filter(distance != 0) %>%
  
#  group_by(ID, High_Task_Incentive
           #,Political.Leaning
#  ) %>% 
#  summarise(dev = mean(update, na.rm = T),
#            n = n(),
#            dev_se = se_func2(update, n)) 



(-0.496 + 0.154) / 0.496

plot_main_func_bar = function(data ,  
                              col_value = c("red", "darkred", "blue", "darkblue"), 
                              ylab = "Probability of Update",
                              title = "Republicans' Probability of Update Accross Influence Identities",
                              save = "Rep_mb1.png"
                              
){
  
  ggplot(data, aes(x = High_Task_Incentive, y = dev, fill = ID)) +
    facet_grid( ~Subject  ) +
    geom_bar(stat="identity", position = "dodge",  width=0.5) +
    geom_errorbar(aes(ymin = dev - 1.96*dev_se, ymax = dev + 1.96*dev_se), width=.1, position = position_dodge(.5)) +
    scale_fill_manual(values = col_value) +    
    labs(x = "Incentive Level", y = ylab,  fill = "Advisor") +
    theme(plot.title = element_text(face = "bold", size = 14), 
          axis.title.x = element_text(face = "bold", size = 12),
          axis.title.y = element_text(face = "bold", size = 12),
          legend.title = element_text(face = "bold", size = 12),
          legend.text = element_text(size = 11)) + 
    theme(axis.text.x = element_text(face="bold", size=11),
          axis.text.y = element_text(face="bold", size=11),
          strip.text.x = element_text(size = 12, face = "bold"))
  
  
}

# Figure 1
plot_main_func_bar(pooled_plot_dist, 
                   col_value = c("chocolate3", "cadetblue"),
                   ylab = "Amount of Updating",
                   title = "Amount of Update Accross Conditions (Pooled)")

ggsave("pooled_mb_bar_sep_amount.png")


plot_prob_main <-  main_df %>% 
  group_by(Incentive, REP
  ) %>% 
  summarise(Prior_Prob = mean(prior_prob),
            Post_Prob = mean(post_prob),
            Prob_Change = mean(prob_change),
            
            n = n(),
            Prob_Change_se = se_func(prob_change, n),
            
            Prior_Prob_se = se_func(prior_prob, n),
            Post_Prob_se = se_func(post_prob, n)) %>%
  mutate (color_help = paste(Incentive, REP, sep = "")) %>%
  mutate(color_help= factor(color_help, levels = c("Low0", "High0", "Low1", "High1"))) %>%
  mutate(REP = ifelse(REP == 1, "Republican", "Democrat"))


plot_prob_pooled <-  main_df %>% 
  group_by(Incentive, Subject
  ) %>% 
  summarise(Prior_Prob = mean(prior_prob),
            Post_Prob = mean(post_prob),
            Prob_Change = mean(prob_change),
            
            n = n(),
            Prob_Change_se = se_func(prob_change, n),
            
            Prior_Prob_se = se_func(prior_prob, n),
            Post_Prob_se = se_func(post_prob, n))
plot_prob_pooled$Subject = ifelse(plot_prob_pooled$Subject == "REP", "Republican", "Democrat")

# Figure 2

ggplot(data = plot_prob_pooled, aes(x = Incentive, y = Prior_Prob, fill = Subject)) +
  # facet_grid(~ Subject) +
  geom_bar(stat="identity", position = "dodge",  width=0.25) +
  geom_errorbar(aes(ymin=Prior_Prob - 1.96*Prior_Prob_se, ymax = Prior_Prob + 1.96*Prior_Prob_se), width=.1, position = position_dodge(0.25)) +
  scale_y_continuous(#limits = c(50, 70)
    breaks=c(0,25,50,70), labels = function(x) paste0(x, "%"))+
  scale_fill_manual(values = c("steelblue","lightcoral")) +    
  geom_hline(yintercept = 50, linetype = "dashed") +
  labs(x = "Incentive Level in Prior Belief Elicitaiton", y = "Probability of Co-partisan Better") +
  theme(plot.title = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 13),
        axis.title.y = element_text(face = "bold", size = 13),
        legend.title = element_text(face = "bold", size = 13))+
  theme(legend.text=element_text(size=11))+
  
  # legend.position = "none") +
  theme(axis.text.x = element_text(face="bold", size=11),
        axis.text.y = element_text(face="bold", size=11),
        strip.text.x = element_text(size = 11, face = "bold")) 
  ggsave("prior_pooled_sep.png")



plot_prob_change_main = main_df%>%
  group_by(Feedback,Subject)%>% 
  summarise(Prior_Prob = mean(prior_prob),
            Post_Prob = mean(post_prob),
            Prob_Change = mean(prob_change),
            
            n = n(),
            Prob_Change_se = se_func(prob_change, n))%>%
  mutate(Subject = ifelse(Subject == "REP", "Republican", "Democrats"))
plot_prob_change_main$Feedback =ifelse(plot_prob_change_main$Feedback == "Co-Better", "Co-partisan Better", "Counter-partisan Better")

#Figure 3

ggplot(data = plot_prob_change_main, aes(x = Feedback, y = Prob_Change, fill = Subject)) +
  # facet_grid(~ Subject) +
  geom_bar(stat="identity", position = "dodge",  width=0.5) +
  geom_errorbar(aes(ymin=Prob_Change - 1.96*Prob_Change_se, ymax = Prob_Change + 1.96*Prob_Change_se), width=.1, position = position_dodge(0.5)) +
  scale_fill_manual(values = c("steelblue","lightcoral")) +    
  geom_hline(yintercept = 0, linetype = "dashed") +
  labs(x = "Feedback", y = "Change in Probability of Co-partisan Better") +
  theme(plot.title = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 13),
        axis.title.y = element_text(face = "bold", size = 13),
        legend.title = element_text(face = "bold", size = 13))+
  theme(legend.text=element_text(size=11))+
  
  # legend.position = "none") +
  theme(axis.text.x = element_text(face="bold", size=11),
        axis.text.y = element_text(face="bold", size=11),
        strip.text.x = element_text(size = 11, face = "bold")) 
ggsave("prob_change_main_sep.png")



#plot_prob_change_func(plot_prob_change_main, title = "Belief Update of Relative Party Performance (Pooled)", 
#                      save = ".png")





####### Main Results: Main Text and SI Section 3

did_oh_main = lm(  update3~  Oppo_center*High_Incentive_center*Right, data = main_df[main_df$distance!=0, ])  
se1 = coeftest(did_oh_main, vcov = vcovHC(did_oh_main, type = "HC1")) 

did_oh_main_woa = lm(  update2~  Oppo_center*High_Incentive_center*Right, data = main_df[main_df$distance!=0, ])  
se2 = coeftest(did_oh_main_woa, vcov = vcovHC(did_oh_main_woa, type = "HC1")) 

did_oh_main_abs = lm(  update~  Oppo_center*High_Incentive_center*Right, data = main_df[main_df$distance!=0, ])  
se3 = coeftest(did_oh_main_abs, vcov = vcovHC(did_oh_main_abs, type = "HC1")) 

table1 = stargazer(did_oh_main,did_oh_main_woa,did_oh_main_abs, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update","WOA", "Amount of Update"),

                   se        = list(se1[,2],se2[,2],se3[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Right", "Counter * High Incentive", "Counter * Right", "High Incentive * Right", "Counter * High Incentive * Right"),
                  # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{3}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1[grepl("Note",table1)] <- note.latex1

cat (table1, sep = "\n")
#         omit.stat=c("LL","ser","f"), no.space=TRUE)


####################

did_oh_main_full = lm(  update3~  Oppo_center*High_Incentive_center*Right, data = main_df)  
se1_full = coeftest(did_oh_main_full, vcov = vcovHC(did_oh_main_full, type = "HC1")) 

did_oh_main_woa_full = lm(  update2~  Oppo_center*High_Incentive_center*Right, data = main_df)  
se2_full = coeftest(did_oh_main_woa_full, vcov = vcovHC(did_oh_main_woa_full, type = "HC1")) 

did_oh_main_abs_full = lm(  update~  Oppo_center*High_Incentive_center*Right, data = main_df)  
se3_full = coeftest(did_oh_main_abs_full, vcov = vcovHC(did_oh_main_abs_full, type = "HC1")) 

table1_full = stargazer(did_oh_main_full,did_oh_main_woa_full,did_oh_main_abs_full, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update","WOA", "Amount of Update"),
                   
                   se        = list(se1_full[,2],se2_full[,2],se3_full[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Right", "Counter * High Incentive", "Counter * Right", "High Incentive * Right", "Counter * High Incentive * Right"),
                   # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{3}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1_full[grepl("Note",table1_full)] <- note.latex1

cat (table1_full, sep = "\n")

# Main Results

did_oh_main_binary = lm(  update3~  Oppo_center*High_Incentive_center*REP_center, data = main_df[main_df$distance!=0, ])  
se1_binary = coeftest(did_oh_main_binary, vcov = vcovHC(did_oh_main_binary, type = "HC1")) 

did_oh_main_woa_binary = lm(  update2~  Oppo_center*High_Incentive_center*REP_center, data = main_df[main_df$distance!=0, ])  
se2_binary = coeftest(did_oh_main_woa_binary, vcov = vcovHC(did_oh_main_woa_binary, type = "HC1")) 

did_oh_main_abs_binary = lm(  update~  Oppo_center*High_Incentive_center*REP_center, data = main_df[main_df$distance!=0, ])  
se3_binary = coeftest(did_oh_main_abs_binary, vcov = vcovHC(did_oh_main_abs_binary, type = "HC1")) 

table1_binary = stargazer(did_oh_main_binary,did_oh_main_woa_binary,did_oh_main_abs_binary, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update","WOA", "Amount of Update"),
                   
                   se        = list(se1_binary[,2],se2_binary[,2],se3_binary[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Republican (1 = Yes)", "Counter * High Incentive", "Counter * Right", "High Incentive * Right", "Counter * High Incentive * Right"),
                   # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{3}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1_binary[grepl("Note",table1_binary)] <- note.latex1

cat (table1_binary, sep = "\n")
#         omit.stat=c("LL","ser","f"), no.space=TRUE)


########### Prior Belief Elicitation Task ########


incentive_prior_main2 = lm(  prior_prob ~  perf_incentive_center*Right  , data = main_df )
coeftest(incentive_prior_main2, vcov = vcovHC(incentive_prior_main2, type = "HC1"))

table2 = stargazer(incentive_prior_main2, title = "Main Results", align= F, dep.var.labels = c("Probability of Co-partisans Being Better"),
                          
                          se        = list(coeftest(incentive_prior_main2, vcov = vcovHC(incentive_prior_main2, type = "HC1"))[,2]),
                          #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                          covariate.labels=c("High Prior Incentive (1 = Yes)", "Right", "High Prior Incentive * Right"),                        # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                          notes.append = F,
                          omit.stat = "f",
                          notes        = "Robust standard errors in parentheses",
                          star.char = c( "+","*", "**", "***"),
                          column.sep.width = "-30pt",
                          star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table2[grepl("Note",table2)] <- note.latex1

cat (table2, sep = "\n")

##

incentive_prior_main2_binary = lm(  prior_prob ~  perf_incentive_center*REP_center  , data = main_df )
coeftest(incentive_prior_main2_binary, vcov = vcovHC(incentive_prior_main2_binary, type = "HC1"))

table2_binary = stargazer(incentive_prior_main2_binary, title = "Main Results", align= F, dep.var.labels = c("Probability of Co-partisans Being Better"),
                   
                   se        = list(coeftest(incentive_prior_main2_binary, vcov = vcovHC(incentive_prior_main2_binary, type = "HC1"))[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("High Prior Incentive (1 = Yes)", "Republican", "High Prior Incentive * Republican"),                        # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table2_binary[grepl("Note",table2_binary)] <- note.latex1

cat (table2_binary, sep = "\n")

#####

prob_change_main3 = lm(  prob_change~  Feedback_center* perf_incentive_center* Right, data = main_df )
coeftest(prob_change_main3, vcov = vcovHC(prob_change_main3, type = "HC1")) 


table3 = stargazer(prob_change_main3, title = "Main Results", align= F, dep.var.labels = c("Change in Probability of Co-partisans Being Better"),
                          
                          se        = list(coeftest(prob_change_main3, vcov = vcovHC(prob_change_main3, type = "HC1"))[,2]),
                          #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                          covariate.labels=c("Feedback (1 = Counter-Partisan-Better)", "High Prior Incentive (1 = Yes)", "Right", "Feedback * High Prior Incentive","Feedback * Right", "High Prior Incentive * Right" ,"Feedback * High Prior Incentive * Right"),                        # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                          notes.append = F,
                          omit.stat = "f",
                          notes        = "Robust standard errors in parentheses",
                          star.char = c( "+","*", "**", "***"),
                          column.sep.width = "-30pt",
                          star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table3[grepl("Note",table3)] <- note.latex1

cat (table3, sep = "\n")


#####


prob_change_main3_binary = lm(  prob_change~  Feedback_center* perf_incentive_center* REP_center, data = main_df )
coeftest(prob_change_main3_binary, vcov = vcovHC(prob_change_main3_binary, type = "HC1")) 

table3_binary = stargazer(prob_change_main3_binary, title = "Main Results", align= F, dep.var.labels = c("Change in Probability of Co-partisans Being Better"),
                          
                          se        = list(coeftest(prob_change_main3_binary, vcov = vcovHC(prob_change_main3_binary, type = "HC1"))[,2]),
                          #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                          covariate.labels=c("Feedback (1 = Counter-Partisan-Better)", "High Prior Incentive (1 = Yes)", "Republican", "Feedback * High Prior Incentive","Feedback * Republican", "High Prior Incentive * Republican" ,"Feedback * High Prior Incentive * Republican"),                        # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                          notes.append = F,
                          omit.stat = "f",
                          notes        = "Robust standard errors in parentheses",
                          star.char = c( "+","*", "**", "***"),
                          column.sep.width = "-30pt",
                          star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table3_binary[grepl("Note",table3_binary)] <- note.latex1

cat (table3_binary, sep = "\n")

###### Separate Analysis on Dems and Reps SI Section 6


did_oh_main_dem = lm(  update3~  Oppo_center*High_Incentive_center, data = dem_df[dem_df$distance!=0, ])  
coeftest(did_oh_main_dem, vcov = vcovHC(did_oh_main_dem, type = "HC1")) 


table1_dem = stargazer(did_oh_main_dem, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update"),
                   
                   se        = list(coeftest(did_oh_main_dem, vcov = vcovHC(did_oh_main_dem, type = "HC1"))[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Counter * High Incentive"),
                   # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1_dem[grepl("Note",table1_dem)] <- note.latex1

cat (table1_dem, sep = "\n")

###

did_oh_main_rep = lm(  update3~  Oppo_center*High_Incentive_center, data = rep_df[rep_df$distance!=0, ])  
coeftest(did_oh_main_rep, vcov = vcovHC(did_oh_main_rep, type = "HC1")) 

table1_rep = stargazer(did_oh_main_rep, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update"),
                       
                       se        = list(coeftest(did_oh_main_rep, vcov = vcovHC(did_oh_main_rep, type = "HC1"))[,2]),
                       #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                       covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Counter * High Incentive"),
                       # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                       notes.append = F,
                       omit.stat = "f",
                       notes        = "Robust standard errors in parentheses",
                       star.char = c( "+","*", "**", "***"),
                       column.sep.width = "-30pt",
                       star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1_rep[grepl("Note",table1_rep)] <- note.latex1

cat (table1_rep, sep = "\n")


########## Additional Robustness Checks SI Sec 7
did_oh_main_turk = lm(  update3~  Oppo_center*High_Incentive_center*Right, data = df_turk[df_turk$distance!=0, ])  
se1_turk = coeftest(did_oh_main_turk, vcov = vcovHC(did_oh_main_turk, type = "HC1")) 

did_oh_main_woa_turk = lm(  update2~  Oppo_center*High_Incentive_center*Right, data = df_turk[df_turk$distance!=0, ])  
se2_turk = coeftest(did_oh_main_woa_turk, vcov = vcovHC(did_oh_main_woa_turk, type = "HC1")) 

did_oh_main_abs_turk = lm(  update~  Oppo_center*High_Incentive_center*Right, data = df_turk[df_turk$distance!=0, ])  
se3_turk = coeftest(did_oh_main_abs_turk, vcov = vcovHC(did_oh_main_abs_turk, type = "HC1")) 

table1_turk = stargazer(did_oh_main_turk,did_oh_main_woa_turk,did_oh_main_abs_turk, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update","WOA", "Amount of Update"),
                       
                       se        = list(se1_turk[,2],se2_turk[,2],se3_turk[,2]),
                       #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                       covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Right", "Counter * High Incentive", "Counter * Right", "High Incentive * Right", "Counter * High Incentive * Right"),
                       # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                       notes.append = F,
                       omit.stat = "f",
                       notes        = "Robust standard errors in parentheses",
                       star.char = c( "+","*", "**", "***"),
                       column.sep.width = "-30pt",
                       star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{3}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1_turk[grepl("Note",table1_turk)] <- note.latex1

cat (table1_turk, sep = "\n")
##


incentive_prior_main2_turk = lm(  prior_prob ~  perf_incentive_center*Right  , data = df_turk )
coeftest(incentive_prior_main2_turk, vcov = vcovHC(incentive_prior_main2_turk, type = "HC1"))

table2_turk = stargazer(incentive_prior_main2_turk, title = "Main Results", align= F, dep.var.labels = c("Probability of Co-partisans Being Better"),
                   
                   se        = list(coeftest(incentive_prior_main2_turk, vcov = vcovHC(incentive_prior_main2_turk, type = "HC1"))[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("High Prior Incentive (1 = Yes)", "Right", "High Prior Incentive * Right"),                        # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table2_turk[grepl("Note",table2_turk)] <- note.latex1

cat (table2_turk, sep = "\n")

##


prob_change_main3_turk = lm(  prob_change~  Feedback_center* perf_incentive_center* Right, data = df_turk )
coeftest(prob_change_main3_turk, vcov = vcovHC(prob_change_main3_turk, type = "HC1")) 


table3_turk = stargazer(prob_change_main3_turk, title = "Main Results", align= F, dep.var.labels = c("Change in Probability of Co-partisans Being Better"),
                   
                   se        = list(coeftest(prob_change_main3_turk, vcov = vcovHC(prob_change_main3_turk, type = "HC1"))[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("Feedback (1 = Counter-Partisan-Better)", "High Prior Incentive (1 = Yes)", "Right", "Feedback * High Prior Incentive","Feedback * Right", "High Prior Incentive * Right" ,"Feedback * High Prior Incentive * Right"),                        # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{2}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table3_turk[grepl("Note",table3_turk)] <- note.latex1

cat (table3_turk, sep = "\n")
###########


did_oh_main_sub = lm(  update3~  Oppo_center*High_Incentive_center*Right, data = main_df_sub[main_df_sub$distance!=0, ])  
se1_sub = coeftest(did_oh_main_sub, vcov = vcovHC(did_oh_main_sub, type = "HC1")) 

did_oh_main_woa_sub = lm(  update2~  Oppo_center*High_Incentive_center*Right, data = main_df_sub[main_df_sub$distance!=0, ])  
se2_sub = coeftest(did_oh_main_woa_sub, vcov = vcovHC(did_oh_main_woa_sub, type = "HC1")) 

did_oh_main_abs_sub = lm(  update~  Oppo_center*High_Incentive_center*Right, data = main_df_sub[main_df_sub$distance!=0, ])  
se3_sub = coeftest(did_oh_main_abs_sub, vcov = vcovHC(did_oh_main_abs_sub, type = "HC1")) 

table1_sub = stargazer(did_oh_main_sub,did_oh_main_woa_sub,did_oh_main_abs_sub, title = "Main Results", align= F, dep.var.labels = c("Scaled Amount of Update","WOA", "Amount of Update"),
                   
                   se        = list(se1_sub[,2],se2_sub[,2],se3_sub[,2]),
                   #         omit = c("Age", "Gender", "Educ","z_initial_rating"),
                   covariate.labels=c("Counter-partisan Advisor (1 = Yes)","High Incentive (1 = Yes)", "Right", "Counter * High Incentive", "Counter * Right", "High Incentive * Right", "Counter * High Incentive * Right"),
                   # add.lines=list(c('News Fixed Effects', 'Yes'), c("Control Variables", "Yes")),
                   notes.append = F,
                   omit.stat = "f",
                   notes        = "Robust standard errors in parentheses",
                   star.char = c( "+","*", "**", "***"),
                   column.sep.width = "-30pt",
                   star.cutoffs = c(0.1, .05, .01, .001))

#write.table(table1, "main_tb.txt",row.names = F,quote = F)
note.latex1 <- "\\multicolumn{3}{l} {\\parbox[t]{12cm}{ \\textit{Notes:}$^{+}$p$<$0.1, $^{*}$p$<$0.05; $^{**}$p$<$0.01; $^{***}$p$<$0.001. \\\\
 Robust standard errors in parentheses.}} \\\\"
table1_sub[grepl("Note",table1_sub)] <- note.latex1

cat (table1_sub, sep = "\n")



###########


library(lme4)
summary(lmList(update2 ~ Oppo_center*High_Incentive_center*Right|news_num,data=main_df[main_df$distance!=0, ])) # shows consistency acorss cases


# SI Section 4


ggplot(data=main_df, aes(x = prior_prob, color = Subject, fill = Subject)) + 
  facet_wrap( ~ Subject_Prior_Incentive , nrow = 2) +
  scale_color_manual(values=c("red", "blue"))+
  geom_histogram(      alpha = .2) + 
  geom_vline(xintercept=50, linetype="dotted", size= 1) + 
  
  labs(x = "Prior Probability", y = "Count", title =  "Prior Probability of Co-Partisan Better", color='Subject') +
  theme(plot.title = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 12),
        axis.title.y = element_text(face = "bold", size = 12),
        legend.title = element_text(face = "bold", size = 12)) + 
  theme(axis.text.x = element_text( size=11, angle = 30),
        axis.text.y = element_text( size=11),
        strip.text.x = element_text(size = 11, face = "bold"))+
  ggsave("prior_hist_plot.png")

######################

# SI Section 5


bayes_bm_func = function(a2, b2){a2*100/(a2+b2)}
bayes_var_func = function(a1,b1){a1*b1/( (a1+b1)^2*(a1 + b1 + 1) )}

bayes_hyper_help = c(1, 2, 3, 5, 8, 13, 21, 34)

len = length(bayes_hyper_help)
#
#mutate(a2 = ifelse(FeedbackGroup == 1, a1+17, a1+3),
#       b2 = ifelse(FeedbackGroup == 2, b1+17, b1+3)) %>%
#  mutate(bayes_benchmark = a2 * 100/(a2+b2) ) %>%
#  mutate(bayes_depart = post_prob - bayes_benchmark )%>%

bayes_a1 = data.frame(matrix(nrow = nrow(main_df), ncol = len))
bayes_b1 = data.frame(matrix(nrow = nrow(main_df), ncol = len))
bayes_a2 = data.frame(matrix(nrow = nrow(main_df), ncol = len))
bayes_b2 = data.frame(matrix(nrow = nrow(main_df), ncol = len))
var_prior = data.frame(matrix(nrow = nrow(main_df), ncol = len))
bayes_bm = data.frame(matrix(nrow = nrow(main_df), ncol = len))
bayes_departure = data.frame(matrix(nrow = nrow(main_df), ncol = len))



for(i in 1:nrow(bayes_a1)){
  for(j in 1:len){
    bayes_a1[i, j] = main_df$prior_prob[i]/bayes_hyper_help[j]
    bayes_b1[i, j] = 100 / bayes_hyper_help[j] - main_df$prior_prob[i]/bayes_hyper_help[j]
    
    bayes_a2[i, j] = ifelse(main_df$FeedbackGroup[i] == 1, bayes_a1[i,j]+17, bayes_a1[i,j]+3)
    bayes_b2[i, j] = ifelse(main_df$FeedbackGroup[i] == 2, bayes_b1[i,j]+17, bayes_b1[i,j]+3)
    
    var_prior[i, j] = bayes_var_func( bayes_a1[i,j],  bayes_b1[i,j])
    bayes_bm[i, j] = bayes_bm_func(bayes_a2[i, j], bayes_b2[i, j])
    bayes_departure[i, j] = main_df$post_prob[i] - bayes_bm[i, j]
    
  }
}

var_prior2 = var_prior
for(i in 1:ncol(var_prior)){
  var_prior2[, i] = sqrt(var_prior[,i])
}  


bayes_departure_avg_co_better = apply(bayes_departure[main_df$FeedbackGroup == 1, ],2,mean)
bayes_departure_avg_co_better_se = apply(bayes_departure[main_df$FeedbackGroup == 1, ],2,se_func, sum(main_df$FeedbackGroup == 1))

bayes_departure_avg_counter_better = apply(bayes_departure[main_df$FeedbackGroup == 2, ],2,mean)
bayes_departure_avg_counter_better_se = apply(bayes_departure[main_df$FeedbackGroup == 2, ],2,se_func, sum(main_df$FeedbackGroup == 2))


bayes_var_co_better = round(apply(var_prior2[main_df$FeedbackGroup == 1, ],2,mean),3)*100
bayes_var_counter_better = round(apply(var_prior2[main_df$FeedbackGroup == 2, ],2,mean),3)*100

Type = factor(rep(c("Co-partisan Better", "Counter-partisan Better"), each = len), levels = c("Counter-partisan Better", "Co-partisan Better"))
Depart = c(bayes_departure_avg_co_better, bayes_departure_avg_counter_better)
SD = c(bayes_var_co_better, bayes_var_counter_better)

bayes_benchmark_plot = data.frame(Type,Depart,SD)
bayes_benchmark_plot$se = c(bayes_departure_avg_co_better_se, bayes_departure_avg_counter_better_se)

bayes_benchmark_plot

ggplot(data=bayes_benchmark_plot, aes(x = SD, y = Depart, fill = Type)) + 
  #  facet_wrap( ~ Subject_FB , nrow = 2) +
  scale_fill_manual(values = c("chocolate3", "cadetblue")) +    
  #  geom_histogram(      alpha = .2) + 
  geom_bar(stat="identity", width=1) +
  geom_errorbar(aes(ymin = Depart - 1.96*se, ymax = Depart + 1.96*se), width=.2) +
  scale_x_continuous(labels = function(x) paste0(x, "%"))+
  scale_y_continuous(labels = function(x) paste0(x, "%"))+
  
  geom_hline(yintercept=0, linetype="dotted", size= 1) + 
  
  labs(x = "Average Prior Standard Deviation", y = "Departure from Bayesian Benchmark", fill = "Feedback Type") +
  theme(plot.title = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 12),
        axis.title.y = element_text(face = "bold", size = 12),
        legend.title = element_text(face = "bold", size = 12),
        legend.text = element_text(size = 11)) + 
  theme(axis.text.x = element_text(face="bold", size=11),
        axis.text.y = element_text(face="bold", size=11),
        strip.text.x = element_text(size = 12, face = "bold")) 
ggsave("bayes_benchmark_compare.png")
















# 
# 
# 
# 
# 
# #################
# 
# # SI Section 3
# 
# # Table 3 
# 
# 
# #did_oh_main = plm(  update~  Oppo*High*z_REP + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = main_df)  
# #coeftest(did_oh_main, vcov = vcovHC(did_oh_main, type = "HC1")) 
# 
# # Table 4 
# 
# incentive_prior_main = lm(  prior_prob ~  Incentive*z_REP + factor(group) + Educ + Gender + Age  , data = main_df )
# coeftest(incentive_prior_main, vcov = vcovHC(incentive_prior_main, type = "HC1"))
# 
# # Table 5
# 
# prob_change_main = lm(  prob_change~  Incentive*Feedback*z_REP + factor(group) + Educ + Gender + Age , data = main_df )
# coeftest(prob_change_main, vcov = vcovHC(prob_change_main, type = "HC1")) 
# 
# ####################
# 
# 
# #bayes_depart_main = lm(  bayes_depart ~ Feedback*z_REP + Incentive + group + Educ + Gender + Age , data = main_df )
# #coeftest(bayes_depart_main, vcov = vcovHC(bayes_depart_main, type = "HC1")) 
# 
# ########################
# 
# # SI Section 6 
# 
# # Table 6
# 
# did_oh_main_rep = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = rep_df)  
# coeftest(did_oh_main_rep, vcov = vcovHC(did_oh_main_rep, type = "HC1")) 
# 
# # Table 7
# 
# 
# did_oh_main_dem = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = dem_df)  
# coeftest(did_oh_main_dem, vcov = vcovHC(did_oh_main_dem, type = "HC1")) 
# 
# # Figure 6.1
# plot_main_func_bar(rep_plot_dist, 
#                    col_value = c("chocolate3", "cadetblue"),
#                    ylab = "Amount of Update",
#                    
#                    title = "Republicans' Amount of Update in News Rating Task",
#                    save = "Rep_mb_bar.png")
# 
# # Figure 6.2
# plot_main_func_bar(dem_plot_dist, 
#                    col_value = c("chocolate3", "cadetblue"),
#                    ylab = "Amount of Update",
#                    title = "Democrats' Amount of Update in News Rating Task",
#                    save = "Dem_mb_bar.png")
# 
# 
# # Table 8 
# 
# 
# incentive_prior_rep = lm(  prior_prob ~  Incentive + group + Educ + Gender + Age , data = rep_df )
# coeftest(incentive_prior_rep, vcov = vcovHC(incentive_prior_rep, type = "HC1"))
# 
# # Table 9
# 
# incentive_prior_dem = lm(  prior_prob ~  Incentive + group + Educ + Gender + Age , data = dem_df )
# coeftest(incentive_prior_dem, vcov = vcovHC(incentive_prior_dem, type = "HC1"))
# 
# # Table 10
# 
# prob_change_main_dem = lm(  prob_change~  Incentive*Feedback + factor(group) + Educ + Gender + Age , data = dem_df )
# coeftest(prob_change_main_dem, vcov = vcovHC(prob_change_main_dem, type = "HC1")) 
# 
# #Table 11
# 
# prob_change_main_rep = lm(  prob_change~  Incentive*Feedback + factor(group) + Educ + Gender + Age , data = rep_df )
# coeftest(prob_change_main_rep, vcov = vcovHC(prob_change_main_rep, type = "HC1")) 
# 
# 
# 
# 
# ########################
# 
# # SI Section 7
# 
# # Table 12
# 
# did_oh_main_rm2 = plm(  update~  Oppo*High*z_REP + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = main_df_sub)  
# coeftest(did_oh_main_rm2, vcov = vcovHC(did_oh_main_rm2, type = "HC1")) 
# 
# #did_oh_main_rep_rm2 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = rep_df_sub)  
# #coeftest(did_oh_main_rep_rm2, vcov = vcovHC(did_oh_main_rep_rm2, type = "HC1")) 
# #did_oh_main_dem_rm2 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = dem_df_sub)  
# #coeftest(did_oh_main_dem_rm2, vcov = vcovHC(did_oh_main_dem_rm2, type = "HC1")) 
# 
# # Table 13
# 
# did_oh_main2 = plm(  update2~  Oppo*High*z_REP + z_initial_rating + Educ + Gender + Age , index = "news_num", model = "within", data = main_df)  
# coeftest(did_oh_main2, vcov = vcovHC(did_oh_main2, type = "HC1")) 
# 
# # Table 14, Table 15, Table 16 -> Run the codes for Table 3, 4, 5 using main_df_full instead of main_df
# 
# # Table 17
# 
# did_oh_main_turk = plm(  update~  Oppo*High*z_REP + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = df_turk)  
# coeftest(did_oh_main_turk, vcov = vcovHC(did_oh_main_turk, type = "HC1")) 
# 
# # Table 18
# 
# 
# did_oh_main_rep_turk = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = rep_df_turk)  
# coeftest(did_oh_main_rep_turk, vcov = vcovHC(did_oh_main_rep_turk, type = "HC1")) 
# 
# # Table 19
# 
# did_oh_main_dem_turk = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = dem_df_turk)  
# coeftest(did_oh_main_dem_turk, vcov = vcovHC(did_oh_main_dem_turk, type = "HC1")) 
# 
# # Table 20
# 
# incentive_prior_main_turk = lm(  prior_prob ~  Incentive*z_REP + factor(group) + Educ + Gender + Age  , data = df_turk )
# coeftest(incentive_prior_main_turk, vcov = vcovHC(incentive_prior_main_turk, type = "HC1"))
# 
# # Table 21
# 
# prob_change_main_turk = lm(  prob_change~  Incentive*Feedback*z_REP + factor(group) + Educ + Gender + Age , data = df_turk )
# coeftest(prob_change_main_turk, vcov = vcovHC(prob_change_main_turk, type = "HC1")) 
# 
# 
# ########################
# 
# # SI Section 8
# 
# # Table 22
# 
# 
# did_oh_main_dem1 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = dem_df[dem_df$Political.Leaning == 1, ])  
# coeftest(did_oh_main_dem1, vcov = vcovHC(did_oh_main_dem1, type = "HC1")) 
# 
# did_oh_main_dem2 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = dem_df[dem_df$Political.Leaning == 2, ])  
# coeftest(did_oh_main_dem2, vcov = vcovHC(did_oh_main_dem2, type = "HC1")) 
# 
# did_oh_main_dem3 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = dem_df[dem_df$Political.Leaning == 3, ])  
# coeftest(did_oh_main_dem3, vcov = vcovHC(did_oh_main_dem3, type = "HC1")) 
# 
# # Table 23
# 
# did_oh_main_rep5 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = rep_df[rep_df$Political.Leaning == 5, ])  
# coeftest(did_oh_main_rep5, vcov = vcovHC(did_oh_main_rep5, type = "HC1")) 
# 
# did_oh_main_rep6 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = rep_df[rep_df$Political.Leaning == 6, ])  
# coeftest(did_oh_main_rep6, vcov = vcovHC(did_oh_main_rep6, type = "HC1")) 
# 
# did_oh_main_rep7 = plm(  update~  Oppo*High + z_initial_rating  + Educ + Gender + Age , index = "news_num", model = "within", data = rep_df[rep_df$Political.Leaning == 7, ])  
# coeftest(did_oh_main_rep7, vcov = vcovHC(did_oh_main_rep7, type = "HC1")) 
# 
# 
# 
# ####################### Bayesian Analysis in the main text
# 
# 
# main.bayes.model.weak <- stan_glm(z_update~  Oppo*High*z_REP + z_initial_rating  + Educ + Gender + Age + factor(news_num), data = main_df,
#                                   prior = normal(0, 10, autoscale = FALSE))
# 
# main.bayes.model.gweak <- stan_glm(z_update~  Oppo*High*z_REP  + z_initial_rating + Educ + Gender + Age + factor(news_num), data = main_df,
#                                    prior = normal(0, 1, autoscale = FALSE))
# 
# main.bayes.model.sweak <- stan_glm(z_update~  Oppo*High*z_REP  + z_initial_rating + Educ + Gender + Age + factor(news_num), data = main_df,
#                                    prior = normal(0, 0.1, autoscale = FALSE))
# 
# main.bayes.model.sweak2 <- stan_glm(z_update~  Oppo*High*z_REP  + z_initial_rating + Educ + Gender + Age + factor(news_num), data = main_df,
#                                     prior = normal(0.1, 0.5, autoscale = FALSE))
# 
# main_BF.weak <- bayesfactor_parameters(main.bayes.model.weak, null = 0)
# main_BF.gweak <- bayesfactor_parameters(main.bayes.model.gweak, null = 0)
# main_BF.sweak <- bayesfactor_parameters(main.bayes.model.sweak, null = 0)
# 
# main_BF.sweak2 <- bayesfactor_parameters(main.bayes.model.sweak2, null = 0)
# 
# main_BF.weak
# main_BF.gweak
# main_BF.sweak
# main_BF.sweak2
# 
# 
# 
# rep.bayes.model <- stan_glm(z_update~  Oppo*High + z_initial_rating + Educ + Gender + Age + factor(news_num), data = rep_df,
#                             prior = normal(0.1, 0.5, autoscale = FALSE))
# 
# rep.bayes.model.weak <- stan_glm(z_update~  Oppo*High + z_initial_rating + Educ + Gender + Age + factor(news_num), data = rep_df,
#                                  prior = normal(0, 10, autoscale = FALSE))
# 
# rep.bayes.model.gweak <- stan_glm(z_update~  Oppo*High + z_initial_rating + Educ + Gender + Age + factor(news_num), data = rep_df,
#                                   prior = normal(0, 1, autoscale = FALSE))
# 
# rep.bayes.in_v_out.model = stan_glm(z_update~  Oppo + z_initial_rating + High + Educ + Gender + Age + factor(news_num), data = rep_df,
#                                     prior = normal(0, 1, autoscale = FALSE))
# 
# rep_BF <- bayesfactor_parameters(rep.bayes.model, null = 0)
# rep_BF.weak <- bayesfactor_parameters(rep.bayes.model.weak, null = 0)
# rep_BF.gweak <- bayesfactor_parameters(rep.bayes.model.gweak, null = 0)
# rep_BF.gweak <- bayesfactor_parameters(rep.bayes.in_v_out.model, null = 0)
# 
# 
# rep_BF
# 
# dem.bayes.model <- stan_glm(z_update~  Oppo*High + z_initial_rating + Educ + Gender + Age + factor(news_num), data = dem_df,
#                             prior = normal(0.1, 0.5, autoscale = FALSE))
# 
# dem.bayes.model.weak <- stan_glm(z_update~  Oppo*High + z_initial_rating+ Educ + Gender + Age + factor(news_num), data = dem_df,
#                                  prior = normal(0, 10, autoscale = FALSE))
# 
# dem.bayes.model.gweak <- stan_glm(z_update~  Oppo*High + z_initial_rating+ Educ + Gender + Age + factor(news_num), data = dem_df,
#                                   prior = normal(0, 1, autoscale = FALSE))
# 
# dem_BF <- bayesfactor_parameters(dem.bayes.model, null = 0)
# dem_BF.weak <- bayesfactor_parameters(dem.bayes.model.weak, null = 0)
# dem_BF.gweak <- bayesfactor_parameters(dem.bayes.model.gweak, null = 0)
# 
# 
# 
# 
# 
# 
# library(see)
# plot(main_BF)
